<?php
/**
 * Moral Theme Customizer
 *
 * @package Moral
 */

/**
 * Get all the default values of the theme mods.
 */
function blogbook_get_default_mods() {
	$blogbook_default_mods = array(

		// Footer copyright
		'blogbook_copyright_txt' => sprintf( esc_html__( 'Theme: %1$s by %2$s.', 'blogbook-pro' ), 'Blogbook Pro', '<a href="' . esc_url( 'http://moralthemes.com/' ) . '">Moral Themes</a>' ),

	);

	return apply_filters( 'blogbook_default_mods', $blogbook_default_mods );
}

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function blogbook_customize_register( $wp_customize ) {
	/**
	 * Separator custom control
	 *
	 * @version 1.0.0
	 * @since  1.0.0
	 */
	class Blogbook_Multi_Custom_Control extends WP_Customize_Control {
		/**
		 * Control type
		 *
		 * @var string
		 */
		public $type = 'blogbook-separator';
		/**
		 * Control method
		 *
		 * @since 1.0.0
		 */
		public function render_content() {
			if ( 'blogbook-separator' === $this->type ) : ?>
				<p><hr style="border-color: #222; opacity: 0.2;"></p>
			<?php endif; ?>

			<?php if ( 'blogbook-custom-label' === $this->type ) : ?>
				<label class="customize-control-title"><?php echo wp_kses_post( $this->label );?></label>
			<?php endif; 
		}
	}

	/**
	 * The radio image customize control extends the WP_Customize_Control class.  This class allows
	 * developers to create a list of image radio inputs.
	 *
	 * Note, the `$choices` array is slightly different than normal and should be in the form of
	 * `array(
		 *	$value => array( 'color' => $color_value ),
		 *	$value => array( 'color' => $color_value ),
	 * )`
	 *
	 */

	/**
	 * Radio color customize control.
	 *
	 * @since  3.0.0
	 * @access public
	 */
	class Blogbook_Customize_Control_Radio_Color extends WP_Customize_Control {

		/**
		 * The type of customize control being rendered.
		 *
		 * @since  3.0.0
		 * @access public
		 * @var    string
		 */
		public $type = 'radio-color';

		/**
		 * Add custom parameters to pass to the JS via JSON.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function to_json() {
			parent::to_json();

			// We need to make sure we have the correct color URL.
			foreach ( $this->choices as $value => $args )
				$this->choices[ $value ]['color'] = esc_attr( $args['color'] );

			$this->json['choices'] = $this->choices;
			$this->json['link']    = $this->get_link();
			$this->json['value']   = $this->value();
			$this->json['id']      = $this->id;
		}

		/**
		 * Don't render the content via PHP.  This control is handled with a JS template.
		 *
		 * @since  4.0.0
		 * @access public
		 * @return bool
		 */
		protected function render_content() {}

		/**
		 * Underscore JS template to handle the control's output.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function content_template() { ?>

			<# if ( ! data.choices ) {
				return;
			} #>

			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

			<# _.each( data.choices, function( args, choice ) { #>
				<label>
					<input type="radio" value="{{ choice }}" name="_customize-{{ data.type }}-{{ data.id }}" {{{ data.link }}} <# if ( choice === data.value ) { #> checked="checked" <# } #> />

					<span class="screen-reader-text">{{ args.label }}</span>
					
					<# if ( 'custom' != choice ) { #>
						<span class="color-value" style="background-color: {{ args.color }}"></span>
					<# } else { #>
						<span class="color-value custom-color-value"></span>
					<# } #>
				</label>
			<# } ) #>
		<?php }
	}

	$wp_customize->register_control_type( 'Blogbook_Customize_Control_Radio_Color'       );

	/**
	 * Multiple select customize control.
	 *
	 * @since  3.0.0
	 * @access public
	 */
	class Blogbook_Customize_Control_Multiple_Select extends WP_Customize_Control {

		/**
		 * The type of customize control being rendered.
		 *
		 * @since  3.0.0
		 * @access public
		 * @var    string
		 */
		public $type = 'multiple-select';

		/**
		 * Add custom parameters to pass to the JS via JSON.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function to_json() {
			parent::to_json();

			$this->json['choices'] = $this->choices;
			$this->json['link']    = $this->get_link();
			$this->json['value']   = $this->value();
			$this->json['id']      = $this->id;
		}

		/**
		 * Don't render the content via PHP.  This control is handled with a JS template.
		 *
		 * @since  4.0.0
		 * @access public
		 * @return bool
		 */
		protected function render_content() {}

		/**
		 * Underscore JS template to handle the control's output.
		 *
		 * @since  3.0.0
		 * @access public
		 * @return void
		 */
		public function content_template() { ?>

			<# if ( ! data.choices ) {
				return;
			} #>

			<# if ( data.label ) { #>
				<span class="customize-control-title">{{ data.label }}</span>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{{ data.description }}}</span>
			<# } #>

				<select multiple id="" name="_customize-{{ data.type }}-{{ data.id }}" {{{ data.link }}}>
				<# _.each( data.choices, function( args, choice ) { #>
						<option value="{{ choice }}">{{{args}}}</option>
				<# } ) #>
				</select>
		<?php }
	}
	$wp_customize->register_control_type( 'Blogbook_Customize_Control_Multiple_Select'       );

	$default = blogbook_get_default_mods();

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'blogbook_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'blogbook_customize_partial_blogdescription',
		) );
	}

	/**
	 *
	 * 
	 * Header panel
	 *
	 * 
	 */
	// Header panel
	$wp_customize->add_panel(
		'blogbook_header_panel',
		array(
			'title' => esc_html__( 'Header', 'blogbook-pro' ),
			'priority' => 100
		)
	);

	$wp_customize->get_section( 'title_tagline' )->panel         = 'blogbook_header_panel';

	// Header text display setting
	$wp_customize->add_setting(	
		'blogbook_header_text_display',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'blogbook_header_text_display',
		array(
			'section'		=> 'title_tagline',
			'type'			=> 'checkbox',
			'label'			=> esc_html__( 'Display Site Title and Tagline', 'blogbook-pro' ),
		)
	);

	// Header section
	$wp_customize->add_section(
		'blogbook_header_section',
		array(
			'title' => esc_html__( 'Header', 'blogbook-pro' ),
			'panel' => 'blogbook_header_panel',
		)
	);

	// Header menu sticky enable settings
	$wp_customize->add_setting(
		'blogbook_make_menu_sticky',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => false
		)
	);

	$wp_customize->add_control(
		'blogbook_make_menu_sticky',
		array(
			'section'		=> 'blogbook_header_section',
			'label'			=> esc_html__( 'Make menu sticky.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Header search form settings
	$wp_customize->add_setting(
		'blogbook_show_search',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'blogbook_show_search',
		array(
			'section'		=> 'blogbook_header_section',
			'label'			=> esc_html__( 'Show search.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured posts section
	$wp_customize->add_section(
		'blogbook_featured_posts_section',
		array(
			'title' => esc_html__( 'Featured Posts', 'blogbook-pro' ),
			'panel' => 'blogbook_header_panel',
		)
	);

	// Featured posts enable settings
	$wp_customize->add_setting(
		'blogbook_featured_posts_enable',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true
		)
	);

	$wp_customize->add_control(
		'blogbook_featured_posts_enable',
		array(
			'section'		=> 'blogbook_featured_posts_section',
			'label'			=> esc_html__( 'Enable on Front page.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Featured posts enable settings
	$wp_customize->add_setting(
		'blogbook_featured_posts_content_type',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
			'default' => 'sticky-posts'
		)
	);

	$wp_customize->add_control(
		'blogbook_featured_posts_content_type',
		array(
			'section'		=> 'blogbook_featured_posts_section',
			'label'			=> esc_html__( 'Content type:', 'blogbook-pro' ),
			'description'			=> esc_html__( 'The recent 4 posts will be displayed from the selected content type.', 'blogbook-pro' ),
			'type'			=> 'radio',
			'active_callback' => 'blogbook_if_featured_posts_enable',
			'choices'		=> array( 
					'sticky-posts' => esc_html__( 'Sticky posts', 'blogbook-pro' ),
					'cat' => esc_html__( 'Category', 'blogbook-pro' ),
					'posts' => esc_html__( 'Posts', 'blogbook-pro' ),
					'recent-posts' => esc_html__( 'Recent posts', 'blogbook-pro' ),
			 	)
		)
	);

	// Featured posts category setting
	$wp_customize->add_setting(
		'blogbook_featured_posts_cat',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
		)
	);

	$wp_customize->add_control(
		'blogbook_featured_posts_cat',
		array(
			'section'		=> 'blogbook_featured_posts_section',
			'label'			=> esc_html__( 'Category:', 'blogbook-pro' ),
			'active_callback' => 'blogbook_if_featured_posts_cat',
			'type'			=> 'select',
			'choices'		=> blogbook_get_post_cat_choices(),
		)
	);

	for ( $i=1; $i <= 4; $i++ ) { 
		// Projects post setting
		$wp_customize->add_setting(
			'blogbook_featured_posts_post_' . $i,
			array(
				'sanitize_callback' => 'blogbook_sanitize_dropdown_pages',
			)
		);

		$wp_customize->add_control(
			'blogbook_featured_posts_post_' . $i,
			array(
				'section'		=> 'blogbook_featured_posts_section',
				'label'			=> esc_html__( 'Post ', 'blogbook-pro' ) . $i,
				'active_callback' => 'blogbook_if_featured_posts_post',
				'type'			=> 'select',
				'choices'		=> blogbook_get_post_choices(),
			)
		);
	}

	/**
	 *
	 * General settings panel
	 * 
	 */
	// General settings panel
	$wp_customize->add_panel(
		'blogbook_general_panel',
		array(
			'title' => esc_html__( 'Advanced Settings', 'blogbook-pro' ),
			'priority' => 107
		)
	);

	$wp_customize->get_section( 'colors' )->panel         = 'blogbook_general_panel';
	
	// Header title color setting
	$wp_customize->add_setting(	
		'blogbook_header_title_color',
		array(
			'sanitize_callback' => 'blogbook_sanitize_hex_color',
			'default' => '#5376bb',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'blogbook_header_title_color',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site title Color:', 'blogbook-pro' ),
			)
		)
	);

	// Header tagline color setting
	$wp_customize->add_setting(	
		'blogbook_header_tagline',
		array(
			'sanitize_callback' => 'blogbook_sanitize_hex_color',
			'default' => '#7b7b7b',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'blogbook_header_tagline',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Site tagline Color:', 'blogbook-pro' ),
			)
		)
	);

	// Color scheme setting
	$wp_customize->add_setting(	
		'blogbook_color_scheme',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
			'default'	=> 'blue',
		)
	);

	$wp_customize->add_control( 
		new Blogbook_Customize_Control_Radio_Color( 
		$wp_customize,
		'blogbook_color_scheme',
		array(
			'section'		=> 'colors',
			'type'			=> 'radio-color',
			'label'			=> esc_html__( 'Color scheme:', 'blogbook-pro' ),
			'choices'		=> array( 
				'orange' => array( 
					'color' => '#ff8737'
				),
				'blue' => array( 
					'color' => '#5376bb'
				),
				'green' => array( 
					'color' => '#0cc652'
				),
				'red' => array( 
					'color' => '#E1222A'
				),
				'custom' => array( 
					'color' => '#E1222A'
				),
			),
		)
	)
	);

	// Custom color scheme scheme setting
	$wp_customize->add_setting(	
		'blogbook_custom_color_scheme',
		array(
			'sanitize_callback' => 'blogbook_sanitize_hex_color',
			'default' => '#5376bb',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control( 
		$wp_customize,
			'blogbook_custom_color_scheme',
			array(
				'section'		=> 'colors',
				'label'			=> esc_html__( 'Custom color:', 'blogbook-pro' ),
				'active_callback' => 'blogbook_if_custom_color_scheme',
			)
		)
	);

	$wp_customize->get_section( 'background_image' )->panel         = 'blogbook_general_panel';
	$wp_customize->get_section( 'custom_css' )->panel         = 'blogbook_general_panel';

	/**
	 * General settings
	 */
	// General settings
	$wp_customize->add_section(
		'blogbook_general_section',
		array(
			'title' => esc_html__( 'General', 'blogbook-pro' ),
			'panel' => 'blogbook_general_panel',
		)
	);

	// Enable smoothscroll setting
	$wp_customize->add_setting(
		'blogbook_smoothscroll_enable',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'blogbook_smoothscroll_enable',
		array(
			'section'		=> 'blogbook_general_section',
			'label'			=> esc_html__( 'Enable smooth scroll.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Backtop enable setting
	$wp_customize->add_setting(
		'blogbook_back_to_top_enable',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_back_to_top_enable',
		array(
			'section'		=> 'blogbook_general_section',
			'label'			=> esc_html__( 'Enable Scroll up.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Global Layout
	 */
	// Global Layout
	$wp_customize->add_section(
		'blogbook_global_layout',
		array(
			'title' => esc_html__( 'Global Layout', 'blogbook-pro' ),
			'panel' => 'blogbook_general_panel',
		)
	);

	// Global site layout setting
	$wp_customize->add_setting(
		'blogbook_site_layout',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
			'default' => 'wide',
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'blogbook_site_layout',
		array(
			'section'		=> 'blogbook_global_layout',
			'label'			=> esc_html__( 'Site layout', 'blogbook-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'boxed' => esc_html__( 'Boxed', 'blogbook-pro' ), 
				'wide' => esc_html__( 'Wide', 'blogbook-pro' ), 
				'frame' => esc_html__( 'Frame', 'blogbook-pro' ), 
			),
		)
	);

	// Global archive layout setting
	$wp_customize->add_setting(
		'blogbook_archive_sidebar',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
			'default' => 'both',
		)
	);

	$wp_customize->add_control(
		'blogbook_archive_sidebar',
		array(
			'section'		=> 'blogbook_global_layout',
			'label'			=> esc_html__( 'Archive Sidebar', 'blogbook-pro' ),
			'description'			=> esc_html__( 'This option works on all archive pages like: 404, search, date, category, "Your latest posts" and so on.', 'blogbook-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left Sidebar', 'blogbook-pro' ), 
				'right' => esc_html__( 'Right Sidebar', 'blogbook-pro' ), 
				'both' => esc_html__( 'Both Sidebars', 'blogbook-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'blogbook-pro' ), 
			),
		)
	);

	// Global page layout setting
	$wp_customize->add_setting(
		'blogbook_global_page_layout',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
			'default' => 'both',
		)
	);

	$wp_customize->add_control(
		'blogbook_global_page_layout',
		array(
			'section'		=> 'blogbook_global_layout',
			'label'			=> esc_html__( 'Global page sidebar', 'blogbook-pro' ),
			'description'			=> esc_html__( 'This option works only on single pages including "Posts page". This setting can be overridden for single page from the metabox too.', 'blogbook-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left Sidebar', 'blogbook-pro' ), 
				'right' => esc_html__( 'Right Sidebar', 'blogbook-pro' ), 
				'both' => esc_html__( 'Both Sidebars', 'blogbook-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'blogbook-pro' ), 
			),
		)
	);

	// Global post layout setting
	$wp_customize->add_setting(
		'blogbook_global_post_layout',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
			'default' => 'both',
		)
	);

	$wp_customize->add_control(
		'blogbook_global_post_layout',
		array(
			'section'		=> 'blogbook_global_layout',
			'label'			=> esc_html__( 'Global post sidebar', 'blogbook-pro' ),
			'description'			=> esc_html__( 'This option works only on single posts. This setting can be overridden for single post from the metabox too.', 'blogbook-pro' ),
			'type'			=> 'radio',
			'choices'		=> array( 
				'left' => esc_html__( 'Left Sidebar', 'blogbook-pro' ), 
				'right' => esc_html__( 'Right Sidebar', 'blogbook-pro' ), 
				'both' => esc_html__( 'Both Sidebars', 'blogbook-pro' ), 
				'no' => esc_html__( 'No Sidebar', 'blogbook-pro' ),
			),
		)
	);

	/**
	 * Blog/Archive section 
	 */
	// Blog/Archive section 
	$wp_customize->add_section(
		'blogbook_archive_settings',
		array(
			'title' => esc_html__( 'Archive/Blog', 'blogbook-pro' ),
			'description' => esc_html__( 'Settings for archive pages including blog page too.', 'blogbook-pro' ),
			'panel' => 'blogbook_general_panel',
		)
	);

	// Featured posts category setting
	$wp_customize->add_setting(
		'blogbook_home_blog_exclude_cat',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
		)
	);

	$wp_customize->add_control( new Blogbook_Customize_Control_Multiple_Select ( $wp_customize,
		'blogbook_home_blog_exclude_cat',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Exclude category:', 'blogbook-pro' ),
			'description' => esc_html__( 'Select the category to exclude from the home blog posts. This works only on blog posts.', 'blogbook-pro' ),
			'type'			=> 'multiple-select',
			'choices'		=> blogbook_get_post_cat_choices(),
		)
	) );

	// Archive excerpt setting
	$wp_customize->add_setting(
		'blogbook_archive_excerpt',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default' => esc_html__( 'Read More', 'blogbook-pro' ),
		)
	);

	$wp_customize->add_control(
		'blogbook_archive_excerpt',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Excerpt more text:', 'blogbook-pro' ),
		)
	);

	// Archive excerpt length setting
	$wp_customize->add_setting(
		'blogbook_archive_excerpt_length',
		array(
			'sanitize_callback' => 'blogbook_sanitize_number_range',
			'default' => 60,
		)
	);

	$wp_customize->add_control(
		'blogbook_archive_excerpt_length',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Excerpt more length:', 'blogbook-pro' ),
			'type'			=> 'number',
			'input_attrs'   => array( 'min' => 5 ),
		)
	);

	// Date enable setting
	$wp_customize->add_setting(
		'blogbook_enable_archive_date',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_archive_date',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Enable date.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Tag enable setting
	$wp_customize->add_setting(
		'blogbook_enable_archive_tag',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_archive_tag',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Enable tags.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Comment enable setting
	$wp_customize->add_setting(
		'blogbook_enable_archive_comment',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_archive_comment',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Enable comment count.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Author enable setting
	$wp_customize->add_setting(
		'blogbook_enable_archive_author',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_archive_author',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Enable author.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'blogbook_enable_archive_featured_img',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_archive_featured_img',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Custom title
	$wp_customize->add_setting(
		'blogbook_archive_content_title',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control( new Blogbook_Multi_Custom_Control( $wp_customize,
		'blogbook_archive_content_title',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Content to show:', 'blogbook-pro' ),
			'type'			=> 'blogbook-custom-label',
		) )
	);

	$content_types = array( 
		'title' => array( 
			'default' => true, 
			'title' => esc_html( 'Title', 'blogbook-pro' ) 
		),
		'excerpt' => array( 
			'default' => false, 
			'title' => esc_html( 'Excerpt', 'blogbook-pro' ) 
		), 
		'content' => array( 
			'default' => false, 
			'title' => esc_html( 'Content', 'blogbook-pro' ) 
		), 
	);


	foreach ( $content_types as $key => $content_type ) {
		// Content type setting
		$wp_customize->add_setting(
			'blogbook_enable_archive_' . $key,
			array(
				'sanitize_callback' => 'blogbook_sanitize_checkbox',
				'default' => $content_type['default'],
			)
		);

		$wp_customize->add_control(
			'blogbook_enable_archive_' . $key,
			array(
				'section'		=> 'blogbook_archive_settings',
				'label'			=> $content_type['title'],
				'type'			=> 'checkbox',
			)
		);
	}

	// Pagination type setting
	$wp_customize->add_setting(
		'blogbook_archive_pagination_type',
		array(
			'sanitize_callback' => 'blogbook_sanitize_select',
			'default' => 'numeric',
		)
	);

	$archive_pagination_description = '';
	$archive_pagination_choices = array( 
				'disable' => esc_html__( '--Disable--', 'blogbook-pro' ),
				'numeric' => esc_html__( 'Numeric', 'blogbook-pro' ),
				'older_newer' => esc_html__( 'Older / Newer', 'blogbook-pro' ),
			);
	if ( ! class_exists( 'JetPack' ) ) {
		$archive_pagination_description = sprintf( esc_html__( 'We recommend to install %1$sJetpack%2$s and enable %3$sInfinite Scroll%4$s feature for automatic loading of posts.', 'blogbook-pro' ), '<a target="_blank" href="http://wordpress.org/plugins/jetpack">', '</a>', '<b>', '</b>' );
	} else {
		$archive_pagination_choices['infinite_scroll'] = esc_html__( 'Infinite Load', 'blogbook-pro' );
	}
	$wp_customize->add_control(
		'blogbook_archive_pagination_type',
		array(
			'section'		=> 'blogbook_archive_settings',
			'label'			=> esc_html__( 'Pagination type:', 'blogbook-pro' ),
			'description'			=>  $archive_pagination_description,
			'type'			=> 'select',
			'choices'		=> $archive_pagination_choices,
		)
	);

	/**
	 * Single setting section 
	 */
	// Single setting section 
	$wp_customize->add_section(
		'blogbook_single_settings',
		array(
			'title' => esc_html__( 'Single Posts', 'blogbook-pro' ),
			'description' => esc_html__( 'Settings for all single posts.', 'blogbook-pro' ),
			'panel' => 'blogbook_general_panel',
		)
	);

	// Date enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_date',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_date',
		array(
			'section'		=> 'blogbook_single_settings',
			'label'			=> esc_html__( 'Enable date.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Category enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_cat',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_cat',
		array(
			'section'		=> 'blogbook_single_settings',
			'label'			=> esc_html__( 'Enable category.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Tag enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_tag',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_tag',
		array(
			'section'		=> 'blogbook_single_settings',
			'label'			=> esc_html__( 'Enable tags.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Comment enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_comment',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_comment',
		array(
			'section'		=> 'blogbook_single_settings',
			'label'			=> esc_html__( 'Enable comment.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);


	// Author enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_author',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_author',
		array(
			'section'		=> 'blogbook_single_settings',
			'label'			=> esc_html__( 'Enable author.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_featured_img',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_featured_img',
		array(
			'section'		=> 'blogbook_single_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_pagination',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_pagination',
		array(
			'section'		=> 'blogbook_single_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Single pages setting section 
	 */
	// Single pages setting section 
	$wp_customize->add_section(
		'blogbook_single_page_settings',
		array(
			'title' => esc_html__( 'Single Pages', 'blogbook-pro' ),
			'description' => esc_html__( 'Settings for all single pages.', 'blogbook-pro' ),
			'panel' => 'blogbook_general_panel',
		)
	);

	// Author enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_page_author',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_page_author',
		array(
			'section'		=> 'blogbook_single_page_settings',
			'label'			=> esc_html__( 'Enable author.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Featured image enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_page_featured_img',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_page_featured_img',
		array(
			'section'		=> 'blogbook_single_page_settings',
			'label'			=> esc_html__( 'Enable featured image.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Pagination enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_page_pagination',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_page_pagination',
		array(
			'section'		=> 'blogbook_single_page_settings',
			'label'			=> esc_html__( 'Enable pagination.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Comment enable setting
	$wp_customize->add_setting(
		'blogbook_enable_single_page_comment',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => false,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_single_page_comment',
		array(
			'section'		=> 'blogbook_single_page_settings',
			'label'			=> esc_html__( 'Enable comment.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 * Reset all settings
	 */
	// Reset settings section
	$wp_customize->add_section(
		'blogbook_reset_sections',
		array(
			'title' => esc_html__( 'Reset all', 'blogbook-pro' ),
			'description' => esc_html__( 'Reset all settings to default.', 'blogbook-pro' ),
			'panel' => 'blogbook_general_panel',
		)
	);

	// Reset reset setting
	$wp_customize->add_setting(
		'blogbook_reset_settings',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => false,
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'blogbook_reset_settings',
		array(
			'section'		=> 'blogbook_reset_sections',
			'label'			=> esc_html__( 'Reset all settings?', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	/**
	 *
	 *
	 * Footer copyright
	 *
	 *
	 */
	// Footer copyright
	$wp_customize->add_section(
		'blogbook_footer_section',
		array(
			'title' => esc_html__( 'Footer', 'blogbook-pro' ),
			'priority' => 106,
			// 'panel' => 'blogbook_general_panel',
		)
	);

	// Footer social menu enable setting
	$wp_customize->add_setting(
		'blogbook_enable_footer_social_menu',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_footer_social_menu',
		array(
			'section'		=> 'blogbook_footer_section',
			'label'			=> esc_html__( 'Enable social menu.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer text enable setting
	$wp_customize->add_setting(
		'blogbook_enable_footer_text',
		array(
			'sanitize_callback' => 'blogbook_sanitize_checkbox',
			'default' => true,
		)
	);

	$wp_customize->add_control(
		'blogbook_enable_footer_text',
		array(
			'section'		=> 'blogbook_footer_section',
			'label'			=> esc_html__( 'Enable footer text.', 'blogbook-pro' ),
			'type'			=> 'checkbox',
		)
	);

	// Footer copyright setting
	$wp_customize->add_setting(
		'blogbook_copyright_txt',
		array(
			'sanitize_callback' => 'blogbook_sanitize_html',
			'default' => $default['blogbook_copyright_txt'],
			'transport'	=> 'postMessage',
		)
	);

	$wp_customize->add_control(
		'blogbook_copyright_txt',
		array(
			'section'		=> 'blogbook_footer_section',
			'label'			=> esc_html__( 'Copyright text:', 'blogbook-pro' ),
			'type'			=> 'textarea',
			'active_callback' => 'blogbook_if_footer_text_enable',
		)
	);

	$wp_customize->selective_refresh->add_partial( 
		'blogbook_copyright_txt', 
		array(
	        'selector'            => '#colophon .site-info .footer-copyright',
			'render_callback'     => 'blogbook_copyright_partial',
    	) 
    );
}
add_action( 'customize_register', 'blogbook_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function blogbook_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function blogbook_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function blogbook_customize_preview_js() {
	wp_enqueue_script( 'blogbook-customizer', get_theme_file_uri( '/assets/js/customizer.js' ), array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'blogbook_customize_preview_js' );

/**
 * Binds JS handlers for Customizer controls.
 */
function blogbook_customize_control_js() {


	wp_enqueue_style( 'blogbook-customize-style', get_theme_file_uri( '/assets/css/customize-controls.css' ), array(), '20151215' );

	wp_enqueue_script( 'blogbook-customize-control', get_theme_file_uri( '/assets/js/customize-control.js' ), array( 'jquery', 'customize-controls' ), '20151215', true );
	$localized_data = array( 
		'refresh_msg' => esc_html__( 'Refresh the page after Save and Publish.', 'blogbook-pro' ),
		'reset_msg' => esc_html__( 'Warning!!! This will reset all the settings. Refresh the page after Save and Publish to reset all.', 'blogbook-pro' ),
	);

	wp_localize_script( 'blogbook-customize-control', 'localized_data', $localized_data );
}
add_action( 'customize_controls_enqueue_scripts', 'blogbook_customize_control_js' );

/**
 *
 * Sanitization callbacks.
 * 
 */

/**
 * Checkbox sanitization callback example.
 * 
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function blogbook_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}


/**
 * HEX Color sanitization callback example.
 *
 * - Sanitization: hex_color
 * - Control: text, WP_Customize_Color_Control
 *
 */
function blogbook_sanitize_hex_color( $hex_color, $setting ) {
	// Sanitize $input as a hex value without the hash prefix.
	$hex_color = sanitize_hex_color( $hex_color );
	
	// If $input is a valid hex value, return it; otherwise, return the default.
	return ( ! is_null( $hex_color ) ? $hex_color : $setting->default );
}

/**
 * Image sanitization callback example.
 *
 * Checks the image's file extension and mime type against a whitelist. If they're allowed,
 * send back the filename, otherwise, return the setting default.
 *
 * - Sanitization: image file extension
 * - Control: text, WP_Customize_Image_Control
 */
function blogbook_sanitize_image( $image, $setting ) {
	/*
	 * Array of valid image file types.
	 *
	 * The array includes image mime types that are included in wp_get_mime_types()
	 */
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon',
        'svg'          => 'image/svg+xml'
    );
	// Return an array with file extension and mime_type.
    $file = wp_check_filetype( $image, $mimes );
	// If $image has a valid mime_type, return it; otherwise, return the default.
    return ( $file['ext'] ? $image : $setting->default );
}

/**
 * Select sanitization callback example.
 *
 * - Sanitization: select, multiple-select
 * - Control: select, radio
 */
function blogbook_sanitize_select( $input, $setting ) {
	$choices = $setting->manager->get_control( $setting->id )->choices;
	
	if ( is_array( $input ) ) {
		foreach ( $input as $value ) {
		// Ensure input is a slug.
			$value = sanitize_key( $value );
			
			if ( ! array_key_exists( $value, $choices ) ) {
            	return $setting->default;
        	}
		}
	} else {
		// Ensure input is a slug.
		$input = sanitize_key( $input );
		
		if ( ! array_key_exists( $input, $choices ) ) {
        	return $setting->default;
    	}
	}

	return $input;
}

/**
 * Drop-down Pages sanitization callback example.
 *
 * - Sanitization: dropdown-pages
 * - Control: dropdown-pages
 * 
 */
function blogbook_sanitize_dropdown_pages( $page_id, $setting ) {
	// Ensure $input is an absolute integer.
	$page_id = absint( $page_id );
	
	// If $page_id is an ID of a published page, return it; otherwise, return the default.
	return ( 'publish' == get_post_status( $page_id ) ? $page_id : $setting->default );
}

/**
 * Number Range sanitization callback example.
 *
 * - Sanitization: number_range
 * - Control: number, tel
 * 
 */
function blogbook_sanitize_number_range( $number, $setting ) {
	
	// Ensure input is an absolute integer.
	$number = absint( $number );
	
	// Get the input attributes associated with the setting.
	$atts = $setting->manager->get_control( $setting->id )->input_attrs;
	
	// Get minimum number in the range.
	$min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
	
	// Get maximum number in the range.
	$max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
	
	// Get step.
	$step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
	
	// If the number is within the valid range, return it; otherwise, return the default
	return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}

/**
 * HTML sanitization callback example.
 *
 * - Sanitization: html
 * - Control: text, textarea
 *
 * @param string $html HTML to sanitize.
 * @return string Sanitized HTML.
 */
function blogbook_sanitize_html( $html ) {
	return wp_filter_post_kses( $html );
}

/**
 *
 * Active callbacks.
 * 
 */

/**
 * Check if the featured posts is enabled
 */
function blogbook_if_featured_posts_enable( $control ) {
	return $control->manager->get_setting( 'blogbook_featured_posts_enable' )->value();
}

/**
 * Check if the slider is cat
 */
function blogbook_if_featured_posts_cat( $control ) {
	return blogbook_if_featured_posts_enable( $control ) && 'cat' === $control->manager->get_setting( 'blogbook_featured_posts_content_type' )->value();
}

/**
 * Check if the slider is cat
 */
function blogbook_if_featured_posts_post( $control ) {
	return blogbook_if_featured_posts_enable( $control ) && 'posts' === $control->manager->get_setting( 'blogbook_featured_posts_content_type' )->value();
}

/**
 * Check if the footer text is enabled
 */
function blogbook_if_footer_text_enable( $control ) {
	return $control->manager->get_setting( 'blogbook_enable_footer_text' )->value();
}

/**
 * Check if custom color scheme is enabled
 */
function blogbook_if_custom_color_scheme( $control ) {
	return 'custom' === $control->manager->get_setting( 'blogbook_color_scheme' )->value();
}

/**
 * Selective refresh.
 */

/**
 * Selective refresh for footer copyright.
 */
function blogbook_copyright_partial() {
	return wp_kses_post( get_theme_mod( 'blogbook_copyright_txt' ) );
}