<?php
/**
 * Widget API: WP_Widget_Text class
 *
 * @package Moral Themes
 * @subpackage Blogbook Pro
 */

add_action( 'widgets_init', 'blogbook_register_widgets' );

function blogbook_register_widgets() {
    register_widget( 'Blogbook_Personal_Info_Widget' );
    
    register_widget( 'Blogbook_Recent_Posts_Widget' );

    register_widget( 'Blogbook_Skills_Widget' );
}

class Blogbook_Personal_Info_Widget extends WP_Widget {
 
    public $sections = array();

    function __construct() {
 
        parent::__construct(
            'blogbook-personal-info',  // Base ID
            'Blogbook Personal Info'   // Name
        );
 
        $this->sections = array(
            'intro' => esc_html__( 'Intro', 'blogbook-pro' ),
            'work' => esc_html__( 'Work', 'blogbook-pro' ),
            'places' => esc_html__( 'Places', 'blogbook-pro' ) ,
            'phone' => esc_html__( 'Phone', 'blogbook-pro' ) ,
        );

        $this->sections = apply_filters( 'blogbook_personal_info_widget_sections', $this->sections );
 
    }

    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        echo '<ul>';
            foreach ( $this->sections as $key => $section ) {
                $title = isset( $instance[ $key ] ) ? $instance[ $key ]: '';
                $text =  isset( $instance[ $key . '_text'] ) ? $instance[ $key . '_text'] : '';
                if ( ! empty( $title ) || ! empty( $text ) ) {
                    echo '<li>';
                        echo blogbook_get_svg( array( 'icon' => $key ) );
                        echo '<span>' . apply_filters( 'widget_title', $title ) . '</span>';
                 
                 
                        echo '<small>' . wp_kses_post( $text ) . '</small>';
                    echo '</li>';
                }
            }
        echo '</ul>';
        echo $args['after_widget']; 
 
    }
 
    public function form( $instance ) {
        foreach ( $this->sections as $key => $section ) {
            $title = ! empty( $instance[ $key ] ) ? $instance[ $key ] : '';
            $text = ! empty( $instance[ $key . '_text'] ) ? $instance[ $key . '_text'] : '';
            ?>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>"><?php echo esc_html( $section );; ?></label>
                <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( $key ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $key ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
            </p>
            <p>
                <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( $key . '_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( $key . '_text' ) ); ?>" type="text" cols="30" rows="10"><?php echo esc_attr( $text ); ?></textarea>
            </p>
            <?php
        }
 
    }
 
    public function update( $new_instance, $old_instance ) {
 
        $instance = $old_instance;
 
        foreach ( $this->sections as $key => $section ) {
            $instance[ $key ] = ( ! empty( $new_instance[ $key ] ) ) ? sanitize_text_field( $new_instance[ $key ] ) : '';
            $instance[ $key . '_text'] = ( ! empty( $new_instance[ $key . '_text'] ) ) ? wp_kses_post( $new_instance[ $key . '_text'] ) : '';
        }
 
        return $instance;
    }
 
}

/**
 * Core class used to implement a Recent Posts widget.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
class Blogbook_Recent_Posts_Widget extends WP_Widget {

    /**
     * Sets up a new Recent Posts widget instance.
     *
     * @since 2.8.0
     */
    public function __construct() {
        

        $widget_ops = array(
            'classname'                   => 'blogbook_recent_posts',
            'description'                 => __( 'Your site&#8217;s most recent Posts with featured image.', 'blogbook-pro' ),
            'customize_selective_refresh' => true,
        );
        parent::__construct( 'blogbook-recent-posts', __( 'Blogbook Recent Posts', 'blogbook-pro' ), $widget_ops );
    }

    /**
     * Outputs the content for the current Recent Posts widget instance.
     *
     * @since 2.8.0
     *
     * @param array $args     Display arguments including 'before_title', 'after_title',
     *                        'before_widget', and 'after_widget'.
     * @param array $instance Settings for the current Recent Posts widget instance.
     */
    public function widget( $args, $instance ) {
        if ( ! isset( $args['widget_id'] ) ) {
            $args['widget_id'] = $this->id;
        }

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Posts', 'blogbook-pro' );

        /** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
        if ( ! $number ) {
            $number = 5;
        }
        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

        /**
         * Filters the arguments for the Recent Posts widget.
         *
         * @since 3.4.0
         * @since 4.9.0 Added the `$instance` parameter.
         *
         * @see WP_Query::get_posts()
         *
         * @param array $args     An array of arguments used to retrieve the recent posts.
         * @param array $instance Array of settings for the current widget.
         */
        $r = new WP_Query(
            apply_filters(
                'blogbook_widget_posts_args', array(
                    'posts_per_page'      => $number,
                    'no_found_rows'       => true,
                    'post_status'         => 'publish',
                    'ignore_sticky_posts' => true,
                ), $instance
            )
        );

        if ( ! $r->have_posts() ) {
            return;
        }
        ?>
        <?php echo $args['before_widget']; ?>
        <?php
        if ( $title ) {
            echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
        }
        ?>
        <ul>
            <?php foreach ( $r->posts as $recent_post ) : ?>
                <?php
                $post_title = get_the_title( $recent_post->ID );
                $title      = ( ! empty( $post_title ) ) ? $post_title : __( '(no title)', 'blogbook-pro' );
                ?>
                <li>
                    <a href="<?php the_permalink( $recent_post->ID ); ?>">
                        <?php echo get_the_post_thumbnail( $recent_post->ID, 'thumbnail', array( 'alt' => the_title_attribute( 'echo=0' ) ) ); ?>
                    </a>
                    <h3><a href="<?php the_permalink( $recent_post->ID ); ?>"><?php echo esc_html( $title ); ?></a></h3>
                    <?php if ( $show_date ) : ?>
                        <span class="post-date"><?php echo esc_html( get_the_date( '', $recent_post->ID ) ); ?></span>
                    <?php endif; ?>
                </li>
            <?php endforeach; ?>
        </ul>
        <?php
        echo $args['after_widget'];
    }

    /**
     * Handles updating the settings for the current Recent Posts widget instance.
     *
     * @since 2.8.0
     *
     * @param array $new_instance New settings for this instance as input by the user via
     *                            WP_Widget::form().
     * @param array $old_instance Old settings for this instance.
     * @return array Updated settings to save.
     */
    public function update( $new_instance, $old_instance ) {
        $instance              = $old_instance;
        $instance['title']     = sanitize_text_field( $new_instance['title'] );
        $instance['number']    = (int) $new_instance['number'];
        $instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
        return $instance;
    }

    /**
     * Outputs the settings form for the Recent Posts widget.
     *
     * @since 2.8.0
     *
     * @param array $instance Current settings.
     */
    public function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false; ?>

        <p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'blogbook-pro' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /></p>

        <p><label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'blogbook-pro' ); ?></label>
        <input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" value="<?php echo esc_attr( $number ); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'show_date' ) ); ?>" />
        <label for="<?php echo esc_attr( $this->get_field_id( 'show_date' ) ); ?>"><?php esc_html_e( 'Display post date?', 'blogbook-pro' ); ?></label></p>
<?php
    }
}

class Blogbook_Skills_Widget extends WP_Widget {
 
    public $sections = array();

    function __construct() {
 
        parent::__construct(
            'blogbook-skills',  // Base ID
            'Blogbook Skills'   // Name
        ); 
    }

    public function widget( $args, $instance ) {
        echo $args['before_widget'];
        $title =  $instance[ 'skill_title' ];
        $text =  $instance[ 'skill_content'];
        
        echo blogbook_get_svg( array( 'icon' => 'skills' ) ) . '<span>' . esc_html( $title ) . '</span>';

        if ( ! empty( $text ) ) {
            echo '<ul>';
                    $skill_arr = explode( ',', $text );

                    for ( $i=0; $i < count( $skill_arr ); $i++ ) { 
                        echo '<li>' . $skill_arr[ $i ] . '</li>';
                    }
            echo '</ul>';
        }
        echo $args['after_widget']; 
 
    }
 
    public function form( $instance ) {
        $title = ! empty( $instance[ 'skill_title' ] ) ? $instance[ 'skill_title' ] : '';
        $text = ! empty( $instance[ 'skill_content' ] ) ? $instance[ 'skill_content' ] : '';
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'skill_title' ) ); ?>"><?php echo esc_html_e( 'Title', 'blogbook-pro' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'skill_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'skill_title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'skill_content' ) ); ?>"><?php echo esc_html_e( 'Skills', 'blogbook-pro' ); ?></label></br>
            <small><?php esc_html_e( 'Input the skills separated by comma. E.g: <i>WordPress, JavaScript, PHP</i>', 'blogbook-pro' ); ?></small>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'skill_content' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'skill_content' ) ); ?>" type="text" cols="30" rows="10"><?php echo esc_attr( $text ); ?></textarea>
        </p>
        <?php
 
    }
 
    public function update( $new_instance, $old_instance ) {
 
        $instance = $old_instance;

        $instance[ 'skill_title' ] = ( ! empty( $new_instance[ 'skill_title' ] ) ) ? sanitize_text_field( $new_instance[ 'skill_title' ] ) : '';
        $instance[ 'skill_content'] = ( ! empty( $new_instance[ 'skill_content' ] ) ) ? wp_kses_post( $new_instance[ 'skill_content' ] ) : '';
 
        return $instance;
    }
 
}

